@@ -55,11 +55,29 @@ register_custom_element_class('w:tr', CT_Row)
 
 from docx.oxml.text import CT_Br, CT_P, CT_PPr, CT_R, CT_RPr, CT_Text
 register_custom_element_class('w:b', CT_OnOff)
+register_custom_element_class('w:bCs', CT_OnOff)
 register_custom_element_class('w:br', CT_Br)
+register_custom_element_class('w:caps', CT_OnOff)
+register_custom_element_class('w:cs', CT_OnOff)
+register_custom_element_class('w:dstrike', CT_OnOff)
+register_custom_element_class('w:emboss', CT_OnOff)
 register_custom_element_class('w:i', CT_OnOff)
+register_custom_element_class('w:iCs', CT_OnOff)
+register_custom_element_class('w:imprint', CT_OnOff)
+register_custom_element_class('w:noProof', CT_OnOff)
+register_custom_element_class('w:oMath', CT_OnOff)
+register_custom_element_class('w:outline', CT_OnOff)
 register_custom_element_class('w:p', CT_P)
 register_custom_element_class('w:pPr', CT_PPr)
 register_custom_element_class('w:pStyle', CT_String)
 register_custom_element_class('w:r', CT_R)
 register_custom_element_class('w:rPr', CT_RPr)
+register_custom_element_class('w:rtl', CT_OnOff)
+register_custom_element_class('w:shadow', CT_OnOff)
+register_custom_element_class('w:smallCaps', CT_OnOff)
+register_custom_element_class('w:snapToGrid', CT_OnOff)
+register_custom_element_class('w:specVanish', CT_OnOff)
+register_custom_element_class('w:strike', CT_OnOff)
 register_custom_element_class('w:t', CT_Text)
+register_custom_element_class('w:vanish', CT_OnOff)
+register_custom_element_class('w:webHidden', CT_OnOff)
